clear
set more off

capture log close

log using "ECLS_mma1.log", replace
use X1SESQ5 X1CHRACE X1INTVID X2INTVID X1ASAGE X2ASAGE BCMOMAGE X1CHPREM X1NUMSIB X1HPARNT BCBRTHWT X1CHSEX W1C0 W2C0 X1HHREGN X1MBRTST X1NCATTP X1RMTLS X2MTLSCL using "ecls.dta"

*** Generate global variables
global race "rr_black rr_hispanic rr_asian rr_other"
global base_9months "i.age_9months female"
global base_2years "i.age_2years female"
global ses "i.sesquint"
* Number of siblings, classifications of parents, geographical region
global home "i.num_siblings i.parent_configuration i.region momage_* Mmomage* parentscore_* Mparentscore"
* Birthweight, birth characteristics, multiple birth status
global prenatal "i.birthweight i.days_premature i.multiples"

*************************************
*** Recode Covariates
***************************************
**** Rename some variables
rename X1SESQ5 sesquint
rename X1CHRACE race
rename X1INTVID interviewerid_9months
rename X2INTVID interviewerid_2years
rename X1ASAGE agem_9months
rename X2ASAGE agem_2years
rename BCMOMAGE momage
rename X1NCATTP parentscore
rename X1RMTLS iq_9months
rename X2MTLSCL iq_2years
rename X1MBRTST multiples
rename X1HHREGN region
rename BCBRTHWT weight
rename X1CHPREM days_premature
rename X1NUMSIB num_siblings

* Keep only the observations with observed interviewer id, test scores, and race
 keep if iq_9months != . & iq_9months >= 0 & iq_2years != . & iq_2years >= 0 & interviewerid_9months != . & interviewerid_2years != . & race >= 0


* Missing Values recoded
foreach k in  parentscore weight agem_9months {
	replace `k' = . if (`k' < 0)
}

*** Cap days premature at 77
replace days_premature = 77 if (days_premature > 77 & days_premature != .)

*** Cap number of siblings at 6
replace num_siblings = 6 if num_siblings > 6

*** redefine parent configuration
gen parent_configuration = 0
replace parent_configuration = 1 if (X1HPARNT == 1)
replace parent_configuration = 2 if (X1HPARNT == 4 | X1HPARNT == 5)
replace parent_configuration = 3 if (X1HPARNT == 2 | X1HPARNT == 3 | X1HPARNT == 10)
replace parent_configuration = 4 if (X1HPARNT == 6 | X1HPARNT == 7 | X1HPARNT == 8 | X1HPARNT == 9)

****create our race variable
generate rr_white = (race == 1)
generate rr_black = (race == 2)
generate rr_hispanic = (race == 3 | race == 4)
generate rr_asian = (race == 5)
generate rr_other = (race == 6 | race == 7 | race == 8)

**** Create birthweight variables
gen birthweight = 0
replace birthweight = 1 if (weight < 1500 & weight >= 0)
replace birthweight = 2 if (weight >= 1500 & weight < 2500)
replace birthweight = 3 if (weight >= 2500 & weight < 3500)
replace birthweight = 4 if (weight >= 3500 & weight != .)

*code gender
gen female = (X1CHSEX == 2)

** Mom's age
gen Mmomage = 0
replace Mmomage = 1 if momage==.
replace momage = 0 if Mmomage == 1
for num 1/5: gen momage_X = momage^X

** Generate Child Age Dummies
gen age_9months = agem_9months
replace age_9months = 8 if age_9months <= 8
replace age_9months = 16 if age_9months >= 16
forvalues i = 8/15{
  replace age_9months = `i' if (agem_9months > `i' & agem_9months < (`i' + 1))
}

gen age_2years = agem_2years
replace age_2years = 23 if age_2years <= 23
replace age_2years = 26 if age_2years >= 26
forvalues i = 23/25{
  replace age_2years = `i' if (agem_2years > `i' & agem_2years < (`i' + 1))
}

gen Mparentscore=0
replace Mparentscore = 1 if parentscore == .
replace parentscore = 0 if Mparentscore == 1
for num 1/5: gen parentscore_X = parentscore^X

foreach x of varlist momage_3 momage_4 momage_5 parentscore_3 parentscore_4 parentscore_5 {
	replace `x' = `x' / 100000
}


** standardize test scores

foreach x of varlist iq_9months {
	egen std_`x' = std(`x')
	***this is not properly weighted

	reg std_`x' [pw=W1C0]
	generate holdmean`x'=_coef[_c] if std_`x'!=.
	replace std_`x' = std_`x' - holdmean`x'
	reg std_`x' [pw=W1C0]
	gen holdse`x'=_se[_c] if std_`x'!=.
	egen numobs`x'=count(std_`x') if std_`x'!=.
	gen holdsdratio`x'=holdse`x'*(numobs`x'^.5)
	replace std_`x'=std_`x'/holdsdratio`x'
}
foreach x of varlist iq_2years {
	egen std_`x'=std(`x')
	***this is not properly weighted

	reg std_`x' [pw=W2C0]
	generate holdmean`x'=_coef[_c] if std_`x'!=.
	replace std_`x'=std_`x'-holdmean`x'
	reg std_`x' [pw=W2C0]
	generate holdse`x'=_se[_c] if std_`x'!=.
	egen numobs`x'=count(std_`x') if std_`x'!=.
	gen holdsdratio`x'=holdse`x'*(numobs`x'^.5)
	replace std_`x'=std_`x'/holdsdratio`x'
}



****************
** Table 2 
****************	
reg std_iq_9months $race [pw=W1C0]
outreg2 using "Outreg/table2.out", se br bdec(3) replace
predict residual_9months_1,residuals
scalar coefficients_9months_1=e(N)-e(df_r)
outreg2 using "coef_9months_1.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_1 using "coef_9months_1.out", write append
file write file_9months_1 %#.#g ("k") _tab (coefficients_9months_1) _n
file close file_9months_1

areg std_iq_9months $race [pw=W1C0], absorb(interviewerid_9months)
outreg2 using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_2,residuals
scalar coefficients_9months_2=e(N)-e(df_r)
outreg2 using "coef_9months_2.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_2 using "coef_9months_2.out", write append
file write file_9months_2 %#.#g ("k") _tab (coefficients_9months_2) _n
file close file_9months_2

xi: areg std_iq_9months $race $base_9months [pw=W1C0] , absorb(interviewerid_9months)
outreg2  using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_3,residuals
scalar coefficients_9months_3=e(N)-e(df_r)
outreg2 using "coef_9months_3.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_3 using "coef_9months_3.out", write append
file write file_9months_3 %#.#g ("k") _tab (coefficients_9months_3) _n
file close file_9months_3

xi: areg std_iq_9months $race $base_9months $ses [pw=W1C0] , absorb(interviewerid_9months)
outreg2 using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_4,residuals
scalar coefficients_9months_4=e(N)-e(df_r)
outreg2 using "coef_9months_4.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_4 using "coef_9months_4.out", write append
file write file_9months_4 %#.#g ("k") _tab (coefficients_9months_4) _n
file close file_9months_4

xi: areg std_iq_9months $race $base_9months $ses $home [pw=W1C0] , absorb(interviewerid_9months)
outreg2 using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_5,residuals
scalar coefficients_9months_5=e(N)-e(df_r)
outreg2 using "coef_9months_5.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_5 using "coef_9months_5.out", write append
file write file_9months_5 %#.#g ("k") _tab (coefficients_9months_5) _n
file close file_9months_5

xi: areg std_iq_9months $race $base_9months $ses $home $prenatal [pw=W1C0] , absorb(interviewerid_9months)
outreg2 using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_6,residuals
scalar coefficients_9months_6=e(N)-e(df_r)
outreg2 using "coef_9months_6.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_6 using "coef_9months_6.out", write append
file write file_9months_6 %#.#g ("k") _tab (coefficients_9months_6) _n
file close file_9months_6

outfile residual_9months_* using "residuals_9months.dat", nolabel wide replace


****************
** Table 3 
****************
reg std_iq_2years $race [pw=W2C0]
outreg2 using "Outreg/table3.out", se br bdec(3) replace
predict residual_2years_1,residuals
scalar coefficients_2years_1=e(N)-e(df_r)
outreg2 using "coef_2years_1.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_1 using "coef_2years_1.out", write append
file write file_2years_1 %#.#g ("k") _tab (coefficients_2years_1) _n
file close file_2years_1

areg std_iq_2years $race [pw=W2C0], absorb(interviewerid_2years)
outreg2 using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_2,residuals
scalar coefficients_2years_2=e(N)-e(df_r)
outreg2 using "coef_2years_2.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace 
file open file_2years_2 using "coef_2years_2.out", write append
file write file_2years_2 %#.#g ("k") _tab (coefficients_2years_2) _n
file close file_2years_2

xi: areg std_iq_2years $race $base_2years [pw=W2C0] , absorb(interviewerid_2years)
outreg2  using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_3,residuals
scalar coefficients_2years_3=e(N)-e(df_r)
outreg2 using "coef_2years_3.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_3 using "coef_2years_3.out", write append
file write file_2years_3 %#.#g ("k") _tab (coefficients_2years_3) _n
file close file_2years_3

xi: areg std_iq_2years $race $base_2years $ses [pw=W2C0] , absorb(interviewerid_2years)
outreg2 using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_4,residuals
scalar coefficients_2years_4=e(N)-e(df_r)
outreg2 using "coef_2years_4.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_4 using "coef_2years_4.out", write append
file write file_2years_4 %#.#g ("k") _tab (coefficients_2years_4) _n
file close file_2years_4

xi: areg std_iq_2years $race $base_2years $ses $home [pw=W2C0] , absorb(interviewerid_2years)
outreg2 using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_5,residuals
scalar coefficients_2years_5=e(N)-e(df_r)
outreg2 using "coef_2years_5.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_5 using "coef_2years_5.out", write append
file write file_2years_5 %#.#g ("k") _tab (coefficients_2years_5) _n
file close file_2years_5

xi: areg std_iq_2years $race $base_2years $ses $home $prenatal [pw=W2C0] , absorb(interviewerid_2years)
outreg2 using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_6,residuals
scalar coefficients_2years_6=e(N)-e(df_r)
outreg2 using "coef_2years_6.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_6 using "coef_2years_6.out", write append
file write file_2years_6 %#.#g ("k") _tab (coefficients_2years_6) _n
file close file_2years_6

outfile residual_2years_* using "residuals_2years.dat", nolabel wide replace

log close
