clear
set more off

capture log close

log using "ECLS_mma2.log", replace
use X1SESQ5 X1CHRACE X1INTVID X2INTVID X1ASAGE X2ASAGE BCMOMAGE X1CHPREM X1NUMSIB X1HPARNT BCBRTHWT X1CHSEX W1C0 W2C0 X1HHREGN X1MBRTST X1NCATTP X1RMTLS X2MTLSCL using "ecls.dta"

*** Generate global variables
global race "rr_black rr_hispanic rr_asian rr_other"
global base_9months "female Mmomage Mparentscore Mdays_premature Mweight momage agem_9months weight num_siblings parentscore days_premature"
global ses "i.sesquint i.region i.parent_configuration singleton twin"

global power_9months_2 "momage_2 agem_9months_2 weight_2 num_siblings_2 parentscore_2 days_premature_2"
global power_9months_3 "momage_3 agem_9months_3 weight_3 num_siblings_3 parentscore_3 days_premature_3"
global power_9months_4 "momage_4 agem_9months_4 weight_4 num_siblings_4 parentscore_4 days_premature_4"
global power_9months_5 "momage_5 agem_9months_5 weight_5 num_siblings_5 parentscore_5 days_premature_5"

global base_2years "female Mmomage Mparentscore Mdays_premature Mweight momage agem_2years weight num_siblings parentscore days_premature"

global power_2years_2 "momage_2 agem_years_2 weight_2 num_siblings_2 parentscore_2 days_premature_2"
global power_2years_3 "momage_3 agem_years_3 weight_3 num_siblings_3 parentscore_3 days_premature_3"
global power_2years_4 "momage_4 agem_years_4 weight_4 num_siblings_4 parentscore_4 days_premature_4"
global power_2years_5 "momage_5 agem_years_5 weight_5 num_siblings_5 parentscore_5 days_premature_5"

*************************************
*** Recode Covariates
***************************************
**** Rename some variables
rename X1SESQ5 sesquint
rename X1CHRACE race
rename X1INTVID interviewerid_9months
rename X2INTVID interviewerid_2years
rename X1ASAGE agem_9months
rename X2ASAGE agem_2years
rename BCMOMAGE momage
rename X1NCATTP parentscore
rename X1RMTLS iq_9months
rename X2MTLSCL iq_2years
rename X1MBRTST multiples
rename X1HHREGN region
rename BCBRTHWT weight
rename X1CHPREM days_premature
rename X1NUMSIB num_siblings

* Keep only the observations with observed interviewer id, test scores, and race
 keep if iq_9months != . & iq_9months >= 0 & iq_2years != . & iq_2years >= 0 & interviewerid_9months != . & interviewerid_2years != . & race >= 0


* Missing Values recoded
foreach k in  parentscore weight agem_9months days_premature multiples {
	replace `k' = . if (`k' < 0)
}

*** Cap days premature at 77
replace days_premature = 77 if (days_premature > 77 & days_premature != .)

*** Cap number of siblings at 6
replace num_siblings = 6 if num_siblings > 6

*** redefine parent configuration
gen parent_configuration = 0
replace parent_configuration = 1 if (X1HPARNT == 1)
replace parent_configuration = 2 if (X1HPARNT == 4 | X1HPARNT == 5)
replace parent_configuration = 3 if (X1HPARNT == 2 | X1HPARNT == 3 | X1HPARNT == 10)
replace parent_configuration = 4 if (X1HPARNT == 6 | X1HPARNT == 7 | X1HPARNT == 8 | X1HPARNT == 9)

****create our race variable
generate rr_white = (race == 1)
generate rr_black = (race == 2)
generate rr_hispanic = (race == 3 | race == 4)
generate rr_asian = (race == 5)
generate rr_other = (race == 6 | race == 7 | race == 8)

*code gender and birth
gen female = (X1CHSEX == 2)
gen singleton = (multiples==1)
gen twin = (multiples==2)

** Mom's age
gen Mmomage = 0
replace Mmomage = 1 if momage==.
replace momage = 0 if Mmomage == 1

gen Mparentscore=0
replace Mparentscore = 1 if parentscore == .
replace parentscore = 0 if Mparentscore == 1

gen Mweight=0
replace Mweight = 1 if weight == .
replace weight = 0 if Mweight == 1

gen Mdays_premature =0
replace Mdays_premature = 1 if days_premature == .
replace days_premature = 0 if Mdays_premature == 1

** Create powers
for num 2/5: gen momage_X = (momage/100)^X
for num 2/5: gen parentscore_X = (parentscore/100)^X
for num 2/5: gen weight_X = (weight/10000)^X
for num 2/5: gen num_siblings_X = (num_siblings/10)^X
for num 2/5: gen agem_9months_X = (agem_9months/100)^X
for num 2/5: gen agem_years_X = (agem_2year/100)^X
for num 2/5: gen days_premature_X = (days_premature/100)^X


** standardize test scores

foreach x of varlist iq_9months {
	egen std_`x' = std(`x')
	***this is not properly weighted

	reg std_`x' [pw=W1C0]
	generate holdmean`x'=_coef[_c] if std_`x'!=.
	replace std_`x' = std_`x' - holdmean`x'
	reg std_`x' [pw=W1C0]
	gen holdse`x'=_se[_c] if std_`x'!=.
	egen numobs`x'=count(std_`x') if std_`x'!=.
	gen holdsdratio`x'=holdse`x'*(numobs`x'^.5)
	replace std_`x'=std_`x'/holdsdratio`x'
}
foreach x of varlist iq_2years {
	egen std_`x'=std(`x')
	***this is not properly weighted

	reg std_`x' [pw=W2C0]
	generate holdmean`x'=_coef[_c] if std_`x'!=.
	replace std_`x'=std_`x'-holdmean`x'
	reg std_`x' [pw=W2C0]
	generate holdse`x'=_se[_c] if std_`x'!=.
	egen numobs`x'=count(std_`x') if std_`x'!=.
	gen holdsdratio`x'=holdse`x'*(numobs`x'^.5)
	replace std_`x'=std_`x'/holdsdratio`x'
}



****************
** Table 2 
****************	
reg std_iq_9months $race [pw=W1C0]
outreg2 using "Outreg/table2.out", se br bdec(3) replace
predict residual_9months_1,residuals
scalar coefficients_9months_1=e(N)-e(df_r)
outreg2 using "coef_9months_1.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_1 using "coef_9months_1.out", write append
file write file_9months_1 %#.#g ("k") _tab (coefficients_9months_1) _n
file close file_9months_1

areg std_iq_9months $race [pw=W1C0], absorb(interviewerid_9months)
outreg2 using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_2,residuals
scalar coefficients_9months_2=e(N)-e(df_r)
outreg2 using "coef_9months_2.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_2 using "coef_9months_2.out", write append
file write file_9months_2 %#.#g ("k") _tab (coefficients_9months_2) _n
file close file_9months_2

xi: areg std_iq_9months $race $base_9months [pw=W1C0] , absorb(interviewerid_9months)
outreg2  using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_3,residuals
scalar coefficients_9months_3=e(N)-e(df_r)
outreg2 using "coef_9months_3.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_3 using "coef_9months_3.out", write append
file write file_9months_3 %#.#g ("k") _tab (coefficients_9months_3) _n
file close file_9months_3

xi: areg std_iq_9months $race $base_9months $ses [pw=W1C0] , absorb(interviewerid_9months)
outreg2 using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_4,residuals
scalar coefficients_9months_4=e(N)-e(df_r)
outreg2 using "coef_9months_4.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_4 using "coef_9months_4.out", write append
file write file_9months_4 %#.#g ("k") _tab (coefficients_9months_4) _n
file close file_9months_4

xi: areg std_iq_9months $race $base_9months $ses $power_9months_2 [pw=W1C0] , absorb(interviewerid_9months)
outreg2 using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_5,residuals
scalar coefficients_9months_5=e(N)-e(df_r)
outreg2 using "coef_9months_5.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_5 using "coef_9months_5.out", write append
file write file_9months_5 %#.#g ("k") _tab (coefficients_9months_5) _n
file close file_9months_5

xi: areg std_iq_9months $race $base_9months $ses $power_9months_2 $power_9months_3 [pw=W1C0] , absorb(interviewerid_9months)
outreg2 using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_6,residuals
scalar coefficients_9months_6=e(N)-e(df_r)
outreg2 using "coef_9months_6.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_6 using "coef_9months_6.out", write append
file write file_9months_6 %#.#g ("k") _tab (coefficients_9months_6) _n
file close file_9months_6

xi: areg std_iq_9months $race $base_9months $ses $power_9months_2 $power_9months_3 $power_9months_4 [pw=W1C0] , absorb(interviewerid_9months)
outreg2 using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_7,residuals
scalar coefficients_9months_7=e(N)-e(df_r)
outreg2 using "coef_9months_7.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_7 using "coef_9months_7.out", write append
file write file_9months_7 %#.#g ("k") _tab (coefficients_9months_7) _n
file close file_9months_7

xi: areg std_iq_9months $race $base_9months $ses $power_9months_2 $power_9months_3 $power_9months_4 $power_9months_5 [pw=W1C0] , absorb(interviewerid_9months)
outreg2 using "Outreg/table2.out", se br bdec(3) append
predict residual_9months_8,residuals
scalar coefficients_9months_8=e(N)-e(df_r)
outreg2 using "coef_9months_8.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_9months_8 using "coef_9months_8.out", write append
file write file_9months_8 %#.#g ("k") _tab (coefficients_9months_8) _n
file close file_9months_8

outfile residual_9months_* using "residuals_9months.dat", nolabel wide replace


****************
** Table 3 
****************
reg std_iq_2years $race [pw=W2C0]
outreg2 using "Outreg/table3.out", se br bdec(3) replace
predict residual_2years_1,residuals
scalar coefficients_2years_1=e(N)-e(df_r)
outreg2 using "coef_2years_1.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_1 using "coef_2years_1.out", write append
file write file_2years_1 %#.#g ("k") _tab (coefficients_2years_1) _n
file close file_2years_1

areg std_iq_2years $race [pw=W2C0], absorb(interviewerid_2years)
outreg2 using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_2,residuals
scalar coefficients_2years_2=e(N)-e(df_r)
outreg2 using "coef_2years_2.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace 
file open file_2years_2 using "coef_2years_2.out", write append
file write file_2years_2 %#.#g ("k") _tab (coefficients_2years_2) _n
file close file_2years_2

xi: areg std_iq_2years $race $base_2years [pw=W2C0] , absorb(interviewerid_2years)
outreg2  using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_3,residuals
scalar coefficients_2years_3=e(N)-e(df_r)
outreg2 using "coef_2years_3.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_3 using "coef_2years_3.out", write append
file write file_2years_3 %#.#g ("k") _tab (coefficients_2years_3) _n
file close file_2years_3

xi: areg std_iq_2years $race $base_2years $ses [pw=W2C0] , absorb(interviewerid_2years)
outreg2 using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_4,residuals
scalar coefficients_2years_4=e(N)-e(df_r)
outreg2 using "coef_2years_4.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_4 using "coef_2years_4.out", write append
file write file_2years_4 %#.#g ("k") _tab (coefficients_2years_4) _n
file close file_2years_4

xi: areg std_iq_2years $race $base_2years $ses $power_9months_2 [pw=W2C0] , absorb(interviewerid_2years)
outreg2 using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_5,residuals
scalar coefficients_2years_5=e(N)-e(df_r)
outreg2 using "coef_2years_5.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_5 using "coef_2years_5.out", write append
file write file_2years_5 %#.#g ("k") _tab (coefficients_2years_5) _n
file close file_2years_5

xi: areg std_iq_2years $race $base_2years $ses $power_2years_2 $power_9months_3 [pw=W2C0] , absorb(interviewerid_2years)
outreg2 using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_6,residuals
scalar coefficients_2years_6=e(N)-e(df_r)
outreg2 using "coef_2years_6.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_6 using "coef_2years_6.out", write append
file write file_2years_6 %#.#g ("k") _tab (coefficients_2years_6) _n
file close file_2years_6

xi: areg std_iq_2years $race $base_2years $ses $power_2years_2 $power_2years_3 $power_9months_4 [pw=W2C0] , absorb(interviewerid_2years)
outreg2 using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_7,residuals
scalar coefficients_2years_7=e(N)-e(df_r)
outreg2 using "coef_2years_7.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_7 using "coef_2years_7.out", write append
file write file_2years_7 %#.#g ("k") _tab (coefficients_2years_7) _n
file close file_2years_7

xi: areg std_iq_2years $race $base_2years $ses $power_2years_2 $power_2years_3 $power_2years_4 $power_9months_5 [pw=W2C0] , absorb(interviewerid_2years)
outreg2 using "Outreg/table3.out", se br bdec(3) append
predict residual_2years_8,residuals
scalar coefficients_2years_8=e(N)-e(df_r)
outreg2 using "coef_2years_8.out", stats(coef) auto(5) bfmt(f) noaster noobs nor2 nonotes nolabel replace
file open file_2years_8 using "coef_2years_8.out", write append
file write file_2years_8 %#.#g ("k") _tab (coefficients_2years_8) _n
file close file_2years_8

outfile residual_2years_* using "residuals_2years.dat", nolabel wide replace

log close
