library(quadprog)

# mma weight calculation
# e is nxM matrix of residuals from M models
# tau is Mx1 vector of penalties for each model
# For MMA, tau=k*sig2, where k is number of estimated coefficients and sig2 is estimated variance

mma <- function(e,tau) {
  m=ncol(e)
  a1 <- t(e)%*%e
  a3 <- t(rbind(matrix(1,nrow=1,ncol=m),diag(m),-diag(m)))
  a4 <- rbind(1,matrix(0,nrow=m,ncol=1),matrix(-1,nrow=m,ncol=1))
  QP <- solve.QP(a1,-tau,a3,a4,1)
  w <- QP$solution
  w <- as.matrix(w)
  w <= w*(w>0)
  w <- w/sum(w)
  w <- round(w,3)
}

# ECLS
# 9 Months
xy <- read.table("residuals_9months.dat")
coef1=read.table("coef_9months_1.out",skip=2,colClasses=c("NULL","numeric"))
r1=nrow(coef1)-1
k1=coef1[r1+1,1]
coef1=coef1[1:r1,1]

coef2=read.table("coef_9months_2.out",skip=2,colClasses=c("NULL","numeric"))
r2=nrow(coef2)-1
k2=coef2[r2+1,1]
coef2=coef2[1:r2,1]

coef3=read.table("coef_9months_3.out",skip=2,colClasses=c("NULL","numeric"))
r3=nrow(coef3)-1
k3=coef3[r3+1,1]
coef3=coef3[1:r3,1]

coef4=read.table("coef_9months_4.out",skip=2,colClasses=c("NULL","numeric"))
r4=nrow(coef4)-1
k4=coef4[r4+1,1]
coef4=coef4[1:r4,1]

coef5=read.table("coef_9months_5.out",skip=2,colClasses=c("NULL","numeric"))
r5=nrow(coef5)-1
k5=coef5[r5+1,1]
coef5=coef5[1:r5,1]

coef6=read.table("coef_9months_6.out",skip=2,colClasses=c("NULL","numeric"))
r6=nrow(coef6)-1
k6=coef6[r6+1,1]
coef6=coef6[1:r6,1]

coef7=read.table("coef_9months_7.out",skip=2,colClasses=c("NULL","numeric"))
r7=nrow(coef7)-1
k7=coef7[r7+1,1]
coef7=coef7[1:r7,1]

coef8=read.table("coef_9months_8.out",skip=2,colClasses=c("NULL","numeric"))
r8=nrow(coef8)-1
k8=coef8[r8+1,1]
coef8=coef8[1:r8,1]

k=rbind(k1,k2,k3,k4,k5,k6,k7,k8)

km=k8
rm=r8
m=ncol(xy)
e=as.matrix(xy)
n=nrow(e)
sighat=sum(e[,m]^2)/(n-km)
tau=k*sighat
w=mma(e,tau)

beta1=matrix(0,rm,1)
beta2=matrix(0,rm,1)
beta3=matrix(0,rm,1)
beta4=matrix(0,rm,1)
beta5=matrix(0,rm,1)
beta6=matrix(0,rm,1)
beta7=matrix(0,rm,1)
beta8=matrix(0,rm,1)

beta1[1:r1]=coef1
beta2[1:r2]=coef2
beta3[1:r3]=coef3
beta4[1:r4]=coef4
beta5[1:r5]=coef5
beta6[1:r6]=coef6
beta7[1:r7]=coef7
beta8[1:r8]=coef8
bbeta=cbind(beta1,beta2,beta3,beta4,beta5,beta6,beta7,beta8)
beta=bbeta%*%w
beta=round(beta,3)

options(scipen=999)
sink("ecls_mma2.out", append=FALSE)
cat("ECLS: 9 Months")
cat(" ")
cat("MMA Model Weights")
print(w)
cat(" ")
cat("MMA Coefficient Estimates")
print(beta)
cat(" ")
sink()




# 2 Years
xy <- read.table("residuals_2years.dat")
coef1=read.table("coef_2years_1.out",skip=2,colClasses=c("NULL","numeric"))
r1=nrow(coef1)-1
k1=coef1[r1+1,1]
coef1=coef1[1:r1,1]

coef2=read.table("coef_2years_2.out",skip=2,colClasses=c("NULL","numeric"))
r2=nrow(coef2)-1
k2=coef2[r2+1,1]
coef2=coef2[1:r2,1]

coef3=read.table("coef_2years_3.out",skip=2,colClasses=c("NULL","numeric"))
r3=nrow(coef3)-1
k3=coef3[r3+1,1]
coef3=coef3[1:r3,1]

coef4=read.table("coef_2years_4.out",skip=2,colClasses=c("NULL","numeric"))
r4=nrow(coef4)-1
k4=coef4[r4+1,1]
coef4=coef4[1:r4,1]

coef5=read.table("coef_2years_5.out",skip=2,colClasses=c("NULL","numeric"))
r5=nrow(coef5)-1
k5=coef5[r5+1,1]
coef5=coef5[1:r5,1]

coef6=read.table("coef_2years_6.out",skip=2,colClasses=c("NULL","numeric"))
r6=nrow(coef6)-1
k6=coef6[r6+1,1]
coef6=coef6[1:r6,1]

coef7=read.table("coef_2years_7.out",skip=2,colClasses=c("NULL","numeric"))
r7=nrow(coef7)-1
k7=coef7[r7+1,1]
coef7=coef7[1:r7,1]

coef8=read.table("coef_2years_8.out",skip=2,colClasses=c("NULL","numeric"))
r8=nrow(coef8)-1
k8=coef8[r8+1,1]
coef8=coef8[1:r8,1]

k=rbind(k1,k2,k3,k4,k5,k6,k7,k8)

km=k8
rm=r8
m=ncol(xy)
e=as.matrix(xy)
n=nrow(e)
sighat=sum(e[,m]^2)/(n-km)
tau=k*sighat
w=mma(e,tau)

beta1=matrix(0,rm,1)
beta2=matrix(0,rm,1)
beta3=matrix(0,rm,1)
beta4=matrix(0,rm,1)
beta5=matrix(0,rm,1)
beta6=matrix(0,rm,1)
beta7=matrix(0,rm,1)
beta8=matrix(0,rm,1)

beta1[1:r1]=coef1
beta2[1:r2]=coef2
beta3[1:r3]=coef3
beta4[1:r4]=coef4
beta5[1:r5]=coef5
beta6[1:r6]=coef6
beta7[1:r7]=coef7
beta8[1:r8]=coef8
bbeta=cbind(beta1,beta2,beta3,beta4,beta5,beta6,beta7,beta8)
beta=bbeta%*%w
beta=round(beta,3)

options(scipen=999)
sink("ecls_mma2.out", append=TRUE)
cat("ECLS: 2 Years")
cat(" ")
cat("MMA Model Weights")
print(w)
cat(" ")
cat("MMA Coefficient Estimates")
print(beta)
cat(" ")
sink()
